# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ...model import adapt, Adapter, implements, Model
from ...shell import IManagedModel
from ...ui import IDisplay

from .. import IBuilderProject


@implements(IDisplay)
class BuilderProjectFactory(Model):
    """ The BuilderProjectFactory class is a factory for the default
    implementation of the IBuilderProject interface.
    """

    # The name of the type of the object.
    name = "DIP builder project"

    def __call__(self):
        """ Invoked by the model manager to create the model instance. """

        from .builder_project import BuilderProject

        return BuilderProject()


@adapt(IBuilderProject, to=IManagedModel)
class IBuilderProjectIManagedModelAdapter(Adapter):
    """ Adapt IBuilderProject to IManagedModel. """

    # The native format.
    native_format = 'dip.builder.formats.project'
