# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import functools

from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem

from ...model import observe
from ...plugins import IPlugin, PluginManager, IPluginManager
from ...ui import IDisplay


class PluginsViewer(QTreeWidget):
    """ The PluginsViewer class is a widget that implements a read-only
    visualisation of all plugins.
    """

    def __init__(self):
        """ Initialise the viewer. """

        super().__init__()

        self.setRootIsDecorated(False)
        self.setHeaderLabels(["Identifier", "Plugin", "Enabled", "Requires"])

        ipluginmanager = IPluginManager(PluginManager().instance)
        self._new_plugins(ipluginmanager.plugins)
        observe('plugins', ipluginmanager, self._plugins_changed)

    def _plugins_changed(self, change):
        """ Invoked when the list of plugins changes. """

        # At the moment plugins can only be added.
        self._new_plugins(change.new)

    def _new_plugins(self, plugins):
        """ Add a list of new plugins. """

        for plugin in plugins:
            iplugin = IPlugin(plugin)

            tool_tip = str(plugin)

            idisplay = IDisplay(plugin, exception=False)
            name = '' if idisplay is None else idisplay.name
            if name == '':
                name = tool_tip

            itm = QTreeWidgetItem(self,
                    [iplugin.id, name, "Yes" if iplugin.enabled else "No",
                            ", ".join(iplugin.requires)])
            itm.setToolTip(1, tool_tip)

            observe('enabled', iplugin,
                    functools.partial(self._plugin_state_changed, itm))

    def _plugin_state_changed(self, itm, change):
        """ Invoked when the enabled state of a plugin changes. """

        itm.setText(2, "Yes" if change.new else "No")
