# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import pyqtSignal, QObject


class ChangeTrigger(QObject):
    """ The ChangeTrigger class communicates a change on behalf of a particular
    instance of an attribute.
    """

    # The signal that is emitted when an attribute is changed.
    changed = pyqtSignal(object)


def get_change_trigger(model, name):
    """ Get the change trigger for an attribute of a model.

    :param model:
        is the :class:`~dip.model.Model` instance.
    :param name:
        is the name of the attribute in the model.
    :return:
        the :class:`~dip.model.ChangeTrigger` instance or ``None`` if the
        attribute is not being observed.
    """

    return None if model is None else model.__dict__.get(
            '_dip_change_trigger_' + name)


def notify_observers(name, model, new, old):
    """ Notify any observers about a change to the value of an attribute of a
    model.

    :param name:
        is the name of the attribute in the model.
    :param model:
        is the :class:`~dip.model.Model` instance.
    :param new:
        is the new value of the attribute.
    :param old:
        is the old value of the attribute.
    """

    trigger = get_change_trigger(model, name)

    if trigger is not None:
        # Avoid a circular import.
        from .attribute_change import AttributeChange

        trigger.changed.emit(
                AttributeChange(model=model, name=name, new=new, old=old))
