# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QWizardPage

from ....model import adapt
from ....ui import IWizardPage

from ..single_qlayout_container_adapter import SingleQLayoutContainerAdapter


@adapt(QWizardPage, to=IWizardPage)
class QWizardPageIWizardPageAdapter(SingleQLayoutContainerAdapter):
    """ An adapter to implement IWizardPage for a QWizardPage. """

    def configure(self, properties):
        """ Configure the widget. """

        # The controller maintains the 'acceptable' attribute which must be
        # returned by QWizardPage.isComplete().  We would normally reimplement
        # this in a sub-class, but we allow the binding of a plain QWizardPage
        # so we monkey patch it instead.
        def isComplete():
            return self.acceptable

        self.adaptee.isComplete = isComplete

        super().configure(properties)

    @IWizardPage.acceptable.setter
    def acceptable(self, value):
        """ Invoked to set the acceptable state. """

        # Save for the standard getter.
        self._acceptable = value

        self.adaptee.completeChanged.emit()

    @IWizardPage.subtitle.getter
    def subtitle(self):
        """ Invoked to get the sub-title. """

        return self.adaptee.subTitle()

    @subtitle.setter
    def subtitle(self, value):
        """ Invoked to set the sub-title. """

        self.adaptee.setSubTitle(value)

    @IWizardPage.title.getter
    def title(self):
        """ Invoked to get the title. """

        return self.adaptee.title()

    @title.setter
    def title(self, value):
        """ Invoked to set the title. """

        self.adaptee.setTitle(value)
