# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import List

from .i_dialog import IDialog, DialogButton
from .single_subview_container_factory import SingleSubviewContainerFactory


class Dialog(SingleSubviewContainerFactory):
    """ The Dialog class implements a dialog factory, i.e. it creates views
    that implement the :class:`~dip.ui.IDialog` interface.
    """

    # The contents should always be automatically wrapped in a
    # :class:`~dip.ui.Form`.
    auto_form = 'always'

    # The dialog buttons.
    buttons = List(DialogButton, default=['ok', 'cancel'])

    # The identifier of each widget created by the factory.
    id = 'dip.dialog'

    # The specific interface implemented by the view.
    view_interface = IDialog

    def create_subviews(self, model, controller, view):
        """ Create the sub-views for a containing view.

        :param model:
            is the model.
        :param controller:
            is the controller.
        :param view:
            is the containing view.
        :return:
            the sub-views.
        """

        # Additional factory specific construction.
        IDialog(view).buttons = self.buttons

        return super().create_subviews(model, controller, view)

    @SingleSubviewContainerFactory.controller_factory.default
    def controller_factory(self):
        """ Invoked to return the default controller factory. """

        from .dialog_controller import DialogController

        return DialogController
