# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Enum, Str

from .i_controller import IController
from .i_dock import IDock
from .single_subview_container_factory import SingleSubviewContainerFactory


class Dock(SingleSubviewContainerFactory):
    """ The Dock class implements a dock of a main window. """

    # The dock area that the dock is initially placed in.
    area = Enum('left', 'right', 'top', 'bottom', allow_none=True)

    # The specific interface implemented by the view.
    view_interface = IDock

    # The identifier of an optional collection of actions that the action used
    # to toggle the dock visibility will be placed within.
    within = Str()

    def configure(self, view):
        """ Reimplemented to configure the IDock specific attributes.

        :param view:
            is the view to configure.
        """

        idock = IDock(view)

        if self.area is not None:
            idock.area = self.area

        idock.within = self.within

        super().configure(view)
