# Copyright (c) 2012 Riverbank Computing Limited.


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.model import implements, List, Model
from dip.plugins import IPlugin
from dip.plugins.default_plugin_manager import PluginManager


class Capture(Model):
    """ A utility class for binding to an extension point. """
    captured = List()


class TestPluginManager(unittest.TestCase):
    """ This tests the default plugin manager's handling of plugins. """

    def test_contribution(self):
        """ Test the explicit contribution to an extension point. """

        @implements(IPlugin)
        class TestPlugin(Model):
            id = 'test.plugin'

            def configure(self, plugin_manager): pass

        capture = Capture()

        plugin_manager = PluginManager()
        plugin_manager.bind_extension_point('test.ep', capture, 'captured')

        contribution = object()

        plugin_manager.contribute('test.ep', contribution)

        self.assertIs(capture.captured[0], contribution)


if __name__ == '__main__':
    unittest.main()
