# Copyright (c) 2011 Riverbank Computing Limited.


# FIXME: Fix the automation of the MacOS system-wide menu bar.
import sys

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from PyQt4.QtGui import QApplication, QMainWindow
from PyQt4.QtTest import QTest

from dip.model import Model, observe
from dip.automate import Robot
from dip.ui import Action, Menu, MenuBar


if __name__ == '__main__':
    import sys

    app = QApplication(sys.argv)


class Actions(Model):
    """ This is the widget used to test menu bars and menus. """

    alt_action = Action("Alt Action", id='Menus.alt_action')

    plain_action = Action("Plain Action", id='Menus.plain_action')

    def reset(self):
        """ Reset the internal state. """

        self.alt_action_triggered = False
        self.plain_action_triggered = False

    @observe('alt_action')
    def _alt_action_triggered(self, change):
        """ Invoked when the alt action is triggered. """

        self.alt_action_triggered = True

    @observe('plain_action')
    def _plain_action_triggered(self, change):
        """ Invoked when the plain action is triggered. """

        self.plain_action_triggered = True


ui = None

class TestMenus(unittest.TestCase):
    """ This tests menu bars and menus. """

    def setUp(self):
        """ Initialise the test widget, creating it if necessary. """

        # Create it if this is the first call.
        global ui

        if ui is None:
            ui = QMainWindow()

            self.menu_bar_factory = MenuBar(
                    Menu('Menus.alt_action', title="&Alt Actions"),
                    Menu('Menus.plain_action', title="Plain Actions"),
                    id='MenuBar')

            self.actions = Actions()

            menu_bar = self.menu_bar_factory(self.actions)

            ui.setMenuBar(menu_bar)

        self.actions.reset()

        ui.show()
        QTest.qWaitForWindowShown(ui)
        QApplication.setActiveWindow(ui)

    def tearDown(self):
        """ Tidy up the test widget. """

        ui.hide()

    @unittest.skipIf(sys.platform == 'darwin', "System-wide menu bar not yet automated")
    def test_AltMenu(self):
        """ Test a menu that can use an Alt key to select. """

        Robot.simulate('MenuBar', 'trigger', 'Menus.alt_action')
        self.assertTrue(ui.alt_action_triggered)

    @unittest.skipIf(sys.platform == 'darwin', "System-wide menu bar not yet automated")
    def test_PlainMenu(self):
        """ Test a menu that cannot use an Alt key to select. """

        Robot.simulate('MenuBar', 'trigger', 'Menus.plain_action')
        self.assertTrue(ui.plain_action_triggered)


if __name__ == '__main__':
    unittest.main()
